# moscato

A drop-in asyncio-compatible replacement for `moto`'s `mock_aws()` function,
for mocking `aiobotocore`

## FAQ

Q: Why is it called `moscato`, that's got nothing to do with `moto` or `aio`

A: It's an anagram of `async moto`. Well, technically, `moscato NY` is the 
anagram, but whatever.  